"""
Type annotations for devicefarm service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_devicefarm.client import DeviceFarmClient
    from types_boto3_devicefarm.paginator import (
        GetOfferingStatusPaginator,
        ListArtifactsPaginator,
        ListDeviceInstancesPaginator,
        ListDevicePoolsPaginator,
        ListDevicesPaginator,
        ListInstanceProfilesPaginator,
        ListJobsPaginator,
        ListNetworkProfilesPaginator,
        ListOfferingPromotionsPaginator,
        ListOfferingTransactionsPaginator,
        ListOfferingsPaginator,
        ListProjectsPaginator,
        ListRemoteAccessSessionsPaginator,
        ListRunsPaginator,
        ListSamplesPaginator,
        ListSuitesPaginator,
        ListTestsPaginator,
        ListUniqueProblemsPaginator,
        ListUploadsPaginator,
        ListVPCEConfigurationsPaginator,
    )

    session = Session()
    client: DeviceFarmClient = session.client("devicefarm")

    get_offering_status_paginator: GetOfferingStatusPaginator = client.get_paginator("get_offering_status")
    list_artifacts_paginator: ListArtifactsPaginator = client.get_paginator("list_artifacts")
    list_device_instances_paginator: ListDeviceInstancesPaginator = client.get_paginator("list_device_instances")
    list_device_pools_paginator: ListDevicePoolsPaginator = client.get_paginator("list_device_pools")
    list_devices_paginator: ListDevicesPaginator = client.get_paginator("list_devices")
    list_instance_profiles_paginator: ListInstanceProfilesPaginator = client.get_paginator("list_instance_profiles")
    list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
    list_network_profiles_paginator: ListNetworkProfilesPaginator = client.get_paginator("list_network_profiles")
    list_offering_promotions_paginator: ListOfferingPromotionsPaginator = client.get_paginator("list_offering_promotions")
    list_offering_transactions_paginator: ListOfferingTransactionsPaginator = client.get_paginator("list_offering_transactions")
    list_offerings_paginator: ListOfferingsPaginator = client.get_paginator("list_offerings")
    list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
    list_remote_access_sessions_paginator: ListRemoteAccessSessionsPaginator = client.get_paginator("list_remote_access_sessions")
    list_runs_paginator: ListRunsPaginator = client.get_paginator("list_runs")
    list_samples_paginator: ListSamplesPaginator = client.get_paginator("list_samples")
    list_suites_paginator: ListSuitesPaginator = client.get_paginator("list_suites")
    list_tests_paginator: ListTestsPaginator = client.get_paginator("list_tests")
    list_unique_problems_paginator: ListUniqueProblemsPaginator = client.get_paginator("list_unique_problems")
    list_uploads_paginator: ListUploadsPaginator = client.get_paginator("list_uploads")
    list_vpce_configurations_paginator: ListVPCEConfigurationsPaginator = client.get_paginator("list_vpce_configurations")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    GetOfferingStatusRequestGetOfferingStatusPaginateTypeDef,
    GetOfferingStatusResultTypeDef,
    ListArtifactsRequestListArtifactsPaginateTypeDef,
    ListArtifactsResultTypeDef,
    ListDeviceInstancesRequestListDeviceInstancesPaginateTypeDef,
    ListDeviceInstancesResultTypeDef,
    ListDevicePoolsRequestListDevicePoolsPaginateTypeDef,
    ListDevicePoolsResultTypeDef,
    ListDevicesRequestListDevicesPaginateTypeDef,
    ListDevicesResultTypeDef,
    ListInstanceProfilesRequestListInstanceProfilesPaginateTypeDef,
    ListInstanceProfilesResultTypeDef,
    ListJobsRequestListJobsPaginateTypeDef,
    ListJobsResultTypeDef,
    ListNetworkProfilesRequestListNetworkProfilesPaginateTypeDef,
    ListNetworkProfilesResultTypeDef,
    ListOfferingPromotionsRequestListOfferingPromotionsPaginateTypeDef,
    ListOfferingPromotionsResultTypeDef,
    ListOfferingsRequestListOfferingsPaginateTypeDef,
    ListOfferingsResultTypeDef,
    ListOfferingTransactionsRequestListOfferingTransactionsPaginateTypeDef,
    ListOfferingTransactionsResultTypeDef,
    ListProjectsRequestListProjectsPaginateTypeDef,
    ListProjectsResultTypeDef,
    ListRemoteAccessSessionsRequestListRemoteAccessSessionsPaginateTypeDef,
    ListRemoteAccessSessionsResultTypeDef,
    ListRunsRequestListRunsPaginateTypeDef,
    ListRunsResultTypeDef,
    ListSamplesRequestListSamplesPaginateTypeDef,
    ListSamplesResultTypeDef,
    ListSuitesRequestListSuitesPaginateTypeDef,
    ListSuitesResultTypeDef,
    ListTestsRequestListTestsPaginateTypeDef,
    ListTestsResultTypeDef,
    ListUniqueProblemsRequestListUniqueProblemsPaginateTypeDef,
    ListUniqueProblemsResultTypeDef,
    ListUploadsRequestListUploadsPaginateTypeDef,
    ListUploadsResultTypeDef,
    ListVPCEConfigurationsRequestListVPCEConfigurationsPaginateTypeDef,
    ListVPCEConfigurationsResultTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = (
    "GetOfferingStatusPaginator",
    "ListArtifactsPaginator",
    "ListDeviceInstancesPaginator",
    "ListDevicePoolsPaginator",
    "ListDevicesPaginator",
    "ListInstanceProfilesPaginator",
    "ListJobsPaginator",
    "ListNetworkProfilesPaginator",
    "ListOfferingPromotionsPaginator",
    "ListOfferingTransactionsPaginator",
    "ListOfferingsPaginator",
    "ListProjectsPaginator",
    "ListRemoteAccessSessionsPaginator",
    "ListRunsPaginator",
    "ListSamplesPaginator",
    "ListSuitesPaginator",
    "ListTestsPaginator",
    "ListUniqueProblemsPaginator",
    "ListUploadsPaginator",
    "ListVPCEConfigurationsPaginator",
)

_ItemTypeDef = TypeVar("_ItemTypeDef")

class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """

class GetOfferingStatusPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/GetOfferingStatus.html#DeviceFarm.Paginator.GetOfferingStatus)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#getofferingstatuspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[GetOfferingStatusRequestGetOfferingStatusPaginateTypeDef]
    ) -> _PageIterator[GetOfferingStatusResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/GetOfferingStatus.html#DeviceFarm.Paginator.GetOfferingStatus.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#getofferingstatuspaginator)
        """

class ListArtifactsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListArtifacts.html#DeviceFarm.Paginator.ListArtifacts)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listartifactspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListArtifactsRequestListArtifactsPaginateTypeDef]
    ) -> _PageIterator[ListArtifactsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListArtifacts.html#DeviceFarm.Paginator.ListArtifacts.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listartifactspaginator)
        """

class ListDeviceInstancesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListDeviceInstances.html#DeviceFarm.Paginator.ListDeviceInstances)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listdeviceinstancespaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListDeviceInstancesRequestListDeviceInstancesPaginateTypeDef]
    ) -> _PageIterator[ListDeviceInstancesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListDeviceInstances.html#DeviceFarm.Paginator.ListDeviceInstances.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listdeviceinstancespaginator)
        """

class ListDevicePoolsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListDevicePools.html#DeviceFarm.Paginator.ListDevicePools)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listdevicepoolspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListDevicePoolsRequestListDevicePoolsPaginateTypeDef]
    ) -> _PageIterator[ListDevicePoolsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListDevicePools.html#DeviceFarm.Paginator.ListDevicePools.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listdevicepoolspaginator)
        """

class ListDevicesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListDevices.html#DeviceFarm.Paginator.ListDevices)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listdevicespaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListDevicesRequestListDevicesPaginateTypeDef]
    ) -> _PageIterator[ListDevicesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListDevices.html#DeviceFarm.Paginator.ListDevices.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listdevicespaginator)
        """

class ListInstanceProfilesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListInstanceProfiles.html#DeviceFarm.Paginator.ListInstanceProfiles)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listinstanceprofilespaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListInstanceProfilesRequestListInstanceProfilesPaginateTypeDef]
    ) -> _PageIterator[ListInstanceProfilesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListInstanceProfiles.html#DeviceFarm.Paginator.ListInstanceProfiles.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listinstanceprofilespaginator)
        """

class ListJobsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListJobs.html#DeviceFarm.Paginator.ListJobs)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listjobspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListJobsRequestListJobsPaginateTypeDef]
    ) -> _PageIterator[ListJobsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListJobs.html#DeviceFarm.Paginator.ListJobs.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listjobspaginator)
        """

class ListNetworkProfilesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListNetworkProfiles.html#DeviceFarm.Paginator.ListNetworkProfiles)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listnetworkprofilespaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListNetworkProfilesRequestListNetworkProfilesPaginateTypeDef]
    ) -> _PageIterator[ListNetworkProfilesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListNetworkProfiles.html#DeviceFarm.Paginator.ListNetworkProfiles.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listnetworkprofilespaginator)
        """

class ListOfferingPromotionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListOfferingPromotions.html#DeviceFarm.Paginator.ListOfferingPromotions)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listofferingpromotionspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListOfferingPromotionsRequestListOfferingPromotionsPaginateTypeDef]
    ) -> _PageIterator[ListOfferingPromotionsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListOfferingPromotions.html#DeviceFarm.Paginator.ListOfferingPromotions.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listofferingpromotionspaginator)
        """

class ListOfferingTransactionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListOfferingTransactions.html#DeviceFarm.Paginator.ListOfferingTransactions)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listofferingtransactionspaginator)
    """
    def paginate(
        self,
        **kwargs: Unpack[ListOfferingTransactionsRequestListOfferingTransactionsPaginateTypeDef],
    ) -> _PageIterator[ListOfferingTransactionsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListOfferingTransactions.html#DeviceFarm.Paginator.ListOfferingTransactions.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listofferingtransactionspaginator)
        """

class ListOfferingsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListOfferings.html#DeviceFarm.Paginator.ListOfferings)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listofferingspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListOfferingsRequestListOfferingsPaginateTypeDef]
    ) -> _PageIterator[ListOfferingsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListOfferings.html#DeviceFarm.Paginator.ListOfferings.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listofferingspaginator)
        """

class ListProjectsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListProjects.html#DeviceFarm.Paginator.ListProjects)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listprojectspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListProjectsRequestListProjectsPaginateTypeDef]
    ) -> _PageIterator[ListProjectsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListProjects.html#DeviceFarm.Paginator.ListProjects.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listprojectspaginator)
        """

class ListRemoteAccessSessionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListRemoteAccessSessions.html#DeviceFarm.Paginator.ListRemoteAccessSessions)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listremoteaccesssessionspaginator)
    """
    def paginate(
        self,
        **kwargs: Unpack[ListRemoteAccessSessionsRequestListRemoteAccessSessionsPaginateTypeDef],
    ) -> _PageIterator[ListRemoteAccessSessionsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListRemoteAccessSessions.html#DeviceFarm.Paginator.ListRemoteAccessSessions.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listremoteaccesssessionspaginator)
        """

class ListRunsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListRuns.html#DeviceFarm.Paginator.ListRuns)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listrunspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListRunsRequestListRunsPaginateTypeDef]
    ) -> _PageIterator[ListRunsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListRuns.html#DeviceFarm.Paginator.ListRuns.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listrunspaginator)
        """

class ListSamplesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListSamples.html#DeviceFarm.Paginator.ListSamples)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listsamplespaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListSamplesRequestListSamplesPaginateTypeDef]
    ) -> _PageIterator[ListSamplesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListSamples.html#DeviceFarm.Paginator.ListSamples.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listsamplespaginator)
        """

class ListSuitesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListSuites.html#DeviceFarm.Paginator.ListSuites)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listsuitespaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListSuitesRequestListSuitesPaginateTypeDef]
    ) -> _PageIterator[ListSuitesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListSuites.html#DeviceFarm.Paginator.ListSuites.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listsuitespaginator)
        """

class ListTestsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListTests.html#DeviceFarm.Paginator.ListTests)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listtestspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListTestsRequestListTestsPaginateTypeDef]
    ) -> _PageIterator[ListTestsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListTests.html#DeviceFarm.Paginator.ListTests.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listtestspaginator)
        """

class ListUniqueProblemsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListUniqueProblems.html#DeviceFarm.Paginator.ListUniqueProblems)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listuniqueproblemspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListUniqueProblemsRequestListUniqueProblemsPaginateTypeDef]
    ) -> _PageIterator[ListUniqueProblemsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListUniqueProblems.html#DeviceFarm.Paginator.ListUniqueProblems.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listuniqueproblemspaginator)
        """

class ListUploadsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListUploads.html#DeviceFarm.Paginator.ListUploads)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listuploadspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListUploadsRequestListUploadsPaginateTypeDef]
    ) -> _PageIterator[ListUploadsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListUploads.html#DeviceFarm.Paginator.ListUploads.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listuploadspaginator)
        """

class ListVPCEConfigurationsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListVPCEConfigurations.html#DeviceFarm.Paginator.ListVPCEConfigurations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listvpceconfigurationspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListVPCEConfigurationsRequestListVPCEConfigurationsPaginateTypeDef]
    ) -> _PageIterator[ListVPCEConfigurationsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm/paginator/ListVPCEConfigurations.html#DeviceFarm.Paginator.ListVPCEConfigurations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_devicefarm/paginators/#listvpceconfigurationspaginator)
        """
